#!/bin/sh

# check if there is variable file in /tmp for source. if it's not there, copy it ##
# wms_value.sh by @root_informatica.

if [ -f /tmp/wms_var ]; then
    . /tmp/wms_var
else
    cp $HOME/.config/wms/wms_var /tmp/wms_var
    . /tmp/wms_var
fi

FLAG=$1
# root window id.
RID=$(lsw -r)
# focused window. 
FW=$(pfw)
# variable temporary file.
WMSVAR="/tmp/wms_var"

usage() {
    cat<<EOF
usage:
wms_revalue.sh [ -b, -B, -d, -g, -G, -m, -M, -w, -W]
-d) load default
-g) minimize gaps
-G) maximize
-m) minimize tiling master area
-M) maximize tiling master area
-w) minimize window percentage
-W) maximize window percentage
EOF
}

# default values.
default() {
    # copy wms_var file in /tmp.
    cp $HOME/.config/wms/wms_var /tmp/wms_var
    # give some name to the window manager.
    atomx WM_NAME=wms $(lsw -r) > /dev/null
}

# increase gaps. (+2 pixels)
gap_inc() {
    if [ $GAP -le 40 ]; then
	sed -i "s/^.*\bGAP=\b.*$/GAP=$((GAP + 2))/" $WMSVAR
	wms_usher.sh -t
    fi
}

# decrease gaps. (-2 pixels)
gap_dec() {
    if [ $GAP -ge 2 ]; then
	sed -i "s/^.*\bGAP=\b.*$/GAP=$((GAP - 2))/" $WMSVAR
	wms_usher.sh -t
    fi
}

# increase master area. (+5 pixels)
master_inc() {
    if [ $MP -le 80 ]; then
	sed -i "s/^.*\bMP=\b.*$/MP=$((MP + 5))/" $WMSVAR
	wms_usher.sh -t
    fi
}

# decrease master area. (-5 pixels)
master_dec() {
    if [ $MP -ge 20 ]; then
	sed -i "s/^.*\bMP=\b.*$/MP=$((MP - 5))/" $WMSVAR
	wms_usher.sh -t
    fi
}

# increase window percentage. (+5 %)
windowperc_inc() {
    if [ $WP -le 90 ]; then
	sed -i "s/^.*\bWP=\b.*$/WP=$((WP + 5))/" $WMSVAR
	wms_usher.sh -w
    fi
}

# decrease window percentage. (-5 %)
windowperc_dec() {
    if [ $WP -ge 60 ]; then
	sed -i "s/^.*\bWP=\b.*$/WP=$((WP - 5))/" $WMSVAR
	wms_usher.sh -w
    fi
}

case $FLAG in
    -d)
	default
	;;
    -g)
	gap_dec
	;;
    -G)
	gap_inc
	;;
    -m)
	master_dec
	;;
    -M)
	master_inc
	;;
    -w)
	windowperc_dec
	;;
    -W)
	windowperc_inc
	;;
    *)
	usage
	;;
esac
